@@ -5,10 +5,12 @@ import sys
 import requests
 
 from .utils import colors
-# from .api import basepair
+
+# Exposing infra webapp library
+from .infra.webapp import Analysis, File, Gene, Genome, GenomeFile, Host, Module, Pipeline, Project, Sample, Upload, User
 
 __title__ = 'basepair'
-__version__ = '1.7.5'
+__version__ = '1.7.9'
 __copyright__ = 'Copyright [2017] - [2021] Basepair INC'
 
 
